.. _homogenization-examples-index:

homogenization
==============

.. toctree::
   :maxdepth: 2

   homogenization_opt.py <homogenization-homogenization_opt>
   linear_elastic_mM.py <homogenization-linear_elastic_mM>
   linear_elasticity_opt.py <homogenization-linear_elasticity_opt>
   linear_homogenization.py <homogenization-linear_homogenization>
   linear_homogenization_postproc.py <homogenization-linear_homogenization_postproc>
   linear_homogenization_up.py <homogenization-linear_homogenization_up>
   material_opt.py <homogenization-material_opt>
   nonlinear_homogenization.py <homogenization-nonlinear_homogenization>
   nonlinear_hyperelastic_mM.py <homogenization-nonlinear_hyperelastic_mM>
   perfusion_micro.py <homogenization-perfusion_micro>
   rs_correctors.py <homogenization-rs_correctors>
